/* eslint-disable */
import axios, { AxiosError } from 'axios';

const request = axios.create({
  baseURL: `${process.env.VUE_APP_API_URL}/`,
  headers: {
    Accept: 'application/json',
    'Content-type': 'application/json',
  },
});

const errorConsolePrinter = (error: AxiosError) => {
  if (error.response) {
    // The request was made and the server responded with a status code
    // that falls out of the range of 2xx
    console.log('Error response: (data, status, headers)');
    console.log(error.response.data);
    console.log(error.response.status);
    console.log(error.response.headers);
  } else if (error.request) {
    // The request was made but no response was received
    // `error.request` is an instance of XMLHttpRequest in the browser and an instance of
    // http.ClientRequest in node.js
    console.log(error.request);
  } else {
    // Something happened in setting up the request that triggered an Error
    console.log('Error', error.message);
  }
  console.log('Request config:');
  console.log(error.config);
};

// response interceptors
request.interceptors.response.use(response => response, // Do something with response data
  (error) => {
    errorConsolePrinter(error);
    /**
     * All API errors are handled here.
     * Everything is by default sent to logger.
     * You can also react on any specific HTTP status in the handler if needed.
     */
    return Promise.reject(error.response);
  });

export default request;
